//go:build amd64

package t544

import (
	"archive/zip"
	"bytes"
	"io"
	"unsafe"

	base14 "github.com/fumiama/go-base16384"
)

var cryptoData = base14.DecodeFromString(
	`戒縰幐一丂一一一娠煳樨刀一乀一圀一吷垌脲妘璖蘀丄跾縀一丆橶縐硍笂儸祠婔瓛伄荰且涵箁澜徴唭嵛庋儉犛埫渀皇淛僎侻昰豪楃愨煬尴豀仵矫栐攂縑千瞷劕瞆繍嵜久劒蕨捅臛佤峺蔗毑襱濄葬呟歍癩覥乆萦厰橤刭翖燈伞榠计賎卯嘭测庆蜖予秶浤熦盭偊光紥礌宒梩伂埧禀嚢曉葊杂箼碒播傸类本煻縢萄宴妡藆調矿筌峸螸翣椶儮扴儳贶擣懪皵孽犠嫛縻萍詌奠蛂竀膜蝆茺耈哣絇爃崵蝝滷楷榏篐棔赦僷舆俨剁椦夤垫睩廜胐弑荜藑斛螥呿臬牴竚聈慑蒔猆珟悑譀弭氐桓历哉孔滁勥始浏崜幕仨仞才簦潈纓竔肕浹戯垁捒崒腖坭撅橅婨搅臛孤槟佖濚襹椄梬菀噭癝冾毥蘢嘅旵曫侃懿棘毱蕵烙椁琼傡祤羶椆攨褆枳劭莟蚳蕚巬嘙矲嘬咯彅祫襥幦膯狝楹繦箻潷稛蛿復纉潬攘掜啲滅篇屫悱欧堶矖幁蔝督丝薢聁薊惣橹砖璧碸禱泭賽翲羞俟槗胅費党痼箝玀腅秨唇興溱虝小汁綡它侖叔芴虭墌嚇螖溈熀秓灻媖搫碸綢贷腎嫵兂囟疾貎跧瑘豄殿爥蓆恆榎芤矟訦憄峙坈圪趕熪亙栣柒珯倍塢衑偦楫峾械纙垺爘垜秝謩蒎捤疩汋豽蛢储嗩嵆潲橙蠧市誣楱嬚微茊睙荻肙漦柩荝讞癓禯墕謰墪摏欚笃螼礑皆沵塪艫狁稪索琴夂憤妱堂觛嚹衦竍觠糐翏舭懒莚萻支楰貖许偵呫爔蓐粀艰糬梃枯俏壶謐刂觡枇庿祛妬催歡繩跽洊澎儰覄瞇劾峮穛奤嫆笪孼氁志耡瀀脦壂粲盋宇妕毃嫉娛旍痹吜衦掺臽罦元罧糴淘户惻謵笾囂觔蜐損斢燖莻笠蕟栫其寅祛某簘宭椦觛臃歭脥訍蕱柫絻凯昷翮畗渘球簑忪蛢劂萾娯崎蜃槭斔作曹湲蓣申茮岃撕燩屑譞盼萎裉紦嶰溃簻惆刻簪刵泴恌巰庸筏匸乢誒唛痍徵茽卼帿荛垮浥荝烷桫琯澿涹豘臐跩獌茾藈烧詺豘緗景拾樚滿訄一跿茄稌刔一一渀一一利绰琚乀一丈一傀一侑獣槙呒螉睮匳繑唁丌丬儧脦跛蕇偀掤概蜣裴檮柬欖篠曣葛矊幜晎妌繀胵綔畍偰蟞挚堧賨粚嗩璘匷崍惹幡簱偫泍呸竕尡硱渔豶厾篁擈痘絨茤乯蕞滱簇勃茶絀塐蟖瞅繭唕解誤笉惖肑暙廬罼豚狆咎揊訉妖品沕疗稉狏猊痮觢瑟窇愨椡摓谴祰蒄扫噃盃蜭裣挃崺肖息揁莽焼溒崓荸晩美炏曣聱褎幘珘矐肖滗羶懶帔萉藲璐媹譈哶仜悻衴盈旋穽蠮焛獜粏腨咈猉惼癹竻蘗澃茀氭懺愰灿岷外犅言一跿茄稌刔一一渀一一奚壾脚乀一丈一傀一侕籣槙呒螉睮匴奱攁丈縔冇她赛巭貯恿丞坓玺珏窴萙椓蘈嵌艎悧訇楬砒缎甍菲稻撟摤蘎仛汈奉社忢楉盒曇水碱蜖偧姪繵栤讞恋琗尔沌臔纱懛窃奢筇窴冄榭情憞妡縍磱嬯苜螜惃斓庭繤蕬蝂竨猞腥胒壠纎嵭癞盢抬拱袒笓懚囔幭紒崋詘窄豜爒祽桾礬旬伩觟渺湩穓蒧漞睱亻俸糋华賸帬招狣吼藭圎塘俖佰斯眎緔欇璘撈哷焿涬唖椥暌劧裤蚸担砬氎卼牛禤芗怰條娯啿蒇舆蛂槊睝晽滩譙夌牜一跿茄稌刔一一渀一一塺絏懡偀一亀一僀一俑潢椙揶効灩榓坶氨焱向何盧毿箲贿侁贴劽捝如翕浱杤毴膔謻攴毹菵厽蕴豢矄莕藗瑐苃籷藧斐摗緙藺琒圆奇疃吏儌円祇熁玎籾粆粸说孡羑羙绌婵蟯桚痎喽粦葔歧吽榾涕扖裘橧蓼衒涙虡荟眭矼解窨脸脸堌戌笞蚼簠裏莲薒榘觮杣妌膌膂幅垖摫堫構疜糆琺蟶窩膞椙衟撨旊崾慷擪晁祿宧襼櫗蝾窡眵汳毘覹襟呡譼圫絖蠺章嵻柾瞬崌沌瑎汪祏啜泪嬰氰朜簞尘瑞沬蚼筌葮賒羫粸敳熉埽罾癪覴謳斶夿澭粑肵賫臎姭椬沫濵洈焳焳滨盫覃羙纘繰庴賳縴翗喽瀮唽同蕟禡禎崝浯晳獾槧枅屾澶穷蕴簹疅葴翪蓪壳稝蕬緭乻催贕沩覰俘腤嶩燗讯攦孺唽吞脃夦球敵岒媻崜櫻泓田翗唜賞苧聾試葛惻怍矮皬设抝蛂襹襻恺婻脫裥惫矷焌秳烛籧甍尋弛泌呺膉瓠慁溫脤湋旜請搜蝺裨胵盳廢癫膞姉峫裷控姱琚峬乶娽擋糟柛朌棟脜桋侎泟浩楫寪矷祷狭溏嬯枎唍咂压例澫澣溢艵翇藓捇旞讕婽词婵蔷猹襻熝艪犦苼蕯籸碻灳翽汗蝍篡紌珌文乕僱狎蚣綄掴賟獭罏揼彥嚷熼簹糯洭滌蜺璸蛱菲茦撰諡绑砙当请欯臌珨端戔蓆袘柵政杹烾罓消奟葟柎攼歸紭冊伖燖槫膻眵襴尧澣罀烁脳焳溨苑蟓覫艑矣觓舞毨徑覻堫敾蓊粜苳烾纲愸螾淐森葓薸码焏掋糶豔掇喙见筗詄摰螝趷荧篢禳俘滪昘簙稺爓幷絣奜泺咸裻瓨盫豿佳瓚曧絟噝凟祣厽寫臄爯药碹睜娙甎偻蟖珐诋蓓奟尟続苍憽盭寝咃匃姟浍挝涴氨婜婻萲翗俯枃屘罻搒误曋唜耳汷掹主掝寮矎腽桢许殑呇呧冒瞃仅绝碿穑蟒跆傼撺磎击苴苮受薫專羓僱滈蝱摱櫳奚泷菑菷矬孲譋慛汫澸涏至糷巑粏棹筄矔挗曃襦塸篕纹貘菻翀僓觇跽姷煏卺肔獳脑洿緽垵蘩拡諑盱縲翇嵗眣懧榟棂藧瀸蟫圎毟袮桝浜蕟梾毁厯曅捇僡磡盀琲槒氹廋螰矅螻袚嫸禛絓井篹板慅敜喇疎否薾螰剐孜宫簎痞羧緼徢覸榾抙掯蓛繳碎竧峿桕櫅虨瘘粚咸忲製賓壼膒祹设搝汹撸婤橦樳儑樹樴栽欝橱臩帥跻糆士盫臞羔嵻橅纮葛袥孑臲篷菴婮慹敬倘嫎寪洃玩苹袲簵蜺毬罬磴玴藏泼聅擽琰搐朝檞簏夬溒姌藗棸怘咭簏唗痚纗蟼参屽舃巢况棹嵮豼犊浞萞觥耱苃葠楽徣櫿嗡瞤詶磗紸藕蓣澥牗橮咎傊心儃瞖慎伮讬坳矷择盓濷絫楳氋疷簻詮琗臖藞罢恩蔮毸螕簾儖嘿吞褹攋诧确盱詔撀犴永塘賻烲舨婐岼槲滵扽窖筨熮搌膃乕矣膧薱獏臸榟慅薄觷嶗睴覵唲蕴柡樝拗椛庰籯薿稣潽簥禦煡滌虰想僞荗覛诟吜倆夆奌膌膂盓忧懮桡大粴朚觚芷簏唾莆簽蒍訬狭萚献糮胢攑蒭谼珇甓羵荢蒠蠏泌呢冖篺筌崨畭捜旜豃倏腻坸痓趼嚇愬粔九罹讬硻薲睎嗞训筱褌綇瓮腽誧礕官峄嗣蟽柖贘氮旪懕裺癆慪蟌淯愷虿姦蟮蛢誾伫貇嗹畽趶唽褰滀荵诏媵濯籭煏泺蠚蛫狳竁甬暪檿艑螎紝蕳磮湋赃妺奧菥玽蛖泻肖崴競蚊諬啺机涹徂懗菗痶覢櫎仂元垶敊倬賺炲褺泷茵志蔹焅漦濕旇芏璷懒费椻歡浾葏蛍愍睷螕碢评詫椵讘咇瑇卯卹偍襳睷豟凁织盁牺湸蚓慡蔢璃嵻塘賻磴穥臞薐蟌筡膞榻薝喸瞋浗婋苏緆斎毼瀩嬮磰珥譧淞堃會泌呦熛紅夃秆磬膕獳赿栠蚅膇竁璮蚹讈圶聑苑菇喽焮泶掩蛳薵笯糯俄覉茵讌粵燦殰苿搢糷尵莪夿愠奨岈洱棋溢幾诛愍蝹礖斾号諏志脆柃滢灍羖憅嬆薙媅宜嵻硴話觚肇絻峓田羷蝼肩費菍畛籆刿哬紥疺疎楡婧毰秆瓽憛硘誩嶝簏兆燇之嗟欸蟞叹煖疦覿曃斞專抟汰蘨猜窪粏嫝涭焍泷猕荴衏巶榷肾沚詪蘒笷榑漏羓埣矅蜽脴槫燦僉硋熇兆渝嫝叏猩欵杮咎傈得埋盱牱瑰脌歱翏玩諗埣尝曟喹补狻沥翟煐杺撾媴賕譯瞖籷羒反珼擱斝滯儃姏崙視瓕綇環覍纹赖詗劂奌窰枌瓖攽罹枖岸賺蒲蟩褭臞讑溙签厼憫哽胙褉嫩能柗栝姥姫豓留孰瘘稙篟癣孶蠵痥豉慆燇下兖燏介啜嬚崜儬橳譴捱请宵濏綧瘻嵥槳缓孟尔見粺箶蚊燕秵旘孩綟甩愌婎赑箷汗蝂肬柱幹絿籣棹柔蕻娽琇冂灑胊狡桥犑硣觮楫兜絻咖诏管秎斝败奒瀛蝉攻岓臟囖哱挎篮橁蠱枫赦蝸綼磣罠乢艹蚉胴艵诧硪賾矗璝懖哈栤听啞讬硻滱觙勃觏儑楟櫱屚艶赴藫员慳裙裢腷厔嶣蝴豻綦奻畷甡炗偅仅蛓翕绠皔檲盹倭畻谶趴蕱惥臑滍觘胗姝憥儶啲塨嫻袊胬襾淠攀丿践伬億匀一丠一一丄嶝簠傀帀一伀丂縀丁艡暛呕讈籢桛渀万跾曟啷緉祯罌世檯賗磝窨夥诺摑贊蕒炯甩唬僟讓垍燿洰芥蝼攝滄挄翈許灘厚俄瘎妬疲歂昲繨楮撨匣絚脩蛋虅嵄仭嘿夕箫妾屒狅焿廯碾舴苎卅豀痵仲涨扨興豊欸譯奭的廿諴竐繏穟珑佼悝谽朗得宂住蔈炩倡哮簅寥蘯槠媎溤爘牜纴裆塆揤汹誃殶寕憪擅槓硥沫溋矠献唩祌榣歴嗒觘簩績筙犀巘屡孕覘椄殞虾垁厧枎猦翨涧展堷蛊吤宿螐璄呤笏稕妱昄一跿茄稌刔一一渀一一尊终簊侀一丘一僀一俑潢椙揶媹灩榀一槿蜀一一一倃偂绐蘐吒历激昔椝叄満纐稴専滲芜蜶儂煣皸爎偏脒媨帘怖咇么楁拙旡幹桎檛佡荍卿暆但翑橈咅著譅吜功琤材民毚抵皀纐稴専囎枻蕻灃栊瓊贉煘粷嗲堏奉膓昪巯松畘稺瞢緬庸螯湼誣亣曨簤儢絇熵疍僬秺炌宋樿撾倸圿婈肠蠧譳蘚曰烮芥祃蚇痙瓮爆仭覻蓐琳埂蓕弙炖蒇商杈呪脥噬嗕蛾嬩紖攠糔羨孁獿苦爑墘詔喇媏憫択薢煺獔涘慜瓝摽栏穋獡艗凹蜵矝氄袧揇圔柽燗甔繋纁昔墼箬襢拨稆曕牖籷攒殙掰莟傖潲巧旀蒥谛穒兛厩藅匟榖杏眠彰怸蜰嬭聋袦令揑峱潆捷朷蚎化斄愞贷櫞牼裐衽洐筚犵絾幷堢來什殽瓚萋兿赘堸愙狠毬晬掷祺緢嫅奩枕炳莽卒榌肐嫄尦峉恱苨汃显禁毙奬薥倴蝍蚲蘟繥篒擌惏琵侨囇玚菄蚓膮櫒倥傿瑻弁痉絺凃瑆絓栯嶽宰廩嵯彂畑瞽淕粩涨贰璨珖磿胘晇粳裐洤蒚觧杷疙褎炸法嵬粺橗昳笻秀焼澶襭帼嚾蛤炌簐擫疃屻亻膊昤賆槮呄緶台堄萷摶纨艈業蛄瞗螼羫咥掤娖愢穩癸独碽溪觐嫊矮藸抳碗壳荜舮九擸哒糃寫娣抾台衁祚謞耪彍烐濹炏箫檣肇娷夣嶾帢薬憮恴章爷懐桛炓茍溹熒擏壇嚮桗吠剡岉臤弲禺矿乨趠褦粰檢胮瑸滂擳纈獙擮槊妜榘貏怺啳款絨萹虹謾噋匥棞財覄坟廼溨菴儋貁碕勜繮槬诶爑瑣珼菓翹藻激敇柯涫孓勥認綹蜑猰欎寜斑蒳浆扖惓羾撰簎犯窌庘傶犿巃虛棦瘭兡移墔焃燠嘸昤侌灢嚰樞垒獧佐搪榞牆膺篱唊癎梇挰喯巫擥剂謽禙莡蓌膧搚臩狆牑昌蝳沅塽圡慚圍萩烊褳幽烑塬凑徿洯等溗焴箶姀畜媎贐嫕粒哰朸擹聻爈獌證榠窹俻擾譸羆桙谷癶聑淽罦疸杷賌牝皅巟膠捨猟懪祘礕贞哙嶾捼粋茊繋蛧譀疩埠玷繎弿玍纄赤薚勉喾刾賯蘽芐泋姌络忺梞蚟居袨屒礁觋忏夗矧噎寯啇贵挪磙痜蝰澦栜詶婂卂橱咡簡婷繜幩譹菂氃朥侯意朶度畀呯茁哽扵胃厛歡忧尘曷肴熴聡蔈爾仱痙屗絲螗栰捾瀉筮栁篻垕灌墺蚧菘湞篰畗瘑肃貓揯烘嵒彔築盭硝徬峦檉捊猰猱皴嵉柟產戍筋悒燑樄贖亍徲扌瀺兏讝沺怅嫿涹碨欧牣詮噔禵盼箮蒰磅甌籚主瞨傿楆塷艂譮剫唁裍甮畔腋厐疖斎祶勲奉堭搣搁刦磜舮爽誩樒谠埊絵房罖債葙謆哪寽瓅峑堗羿尶悩薗慌潘睞痝溱擛峨斠统朸砜帓畼讳椅炽苺衧哉欳氕搸凴慈罴茁菌杴予懕媧犲詷夣衈瑄洤滠塚抜誗褴涖諒槈赳捰胼船广繋婀捵翇塷羄瞏匪莄艶藬失肷孿爠蛁艶淰芏櫆胿廢祟姅諁罞榣緱伇峞文蔁俼崯巔倎賿跞積螒笩貑係枹硻罖簒粻襅琨貎菣嗗槨偿漜挭曙喜杏砦瘾扩咣珣帐七跿戒縰幐一丂一一一勗脫噘一丄一一夀一商厉穥旙僦垥籢昹氦涇牣螸呖妝潤蛁湀七跿戒縰幐一丂一一一幗堷幜一丄一一夀一商厉穥旙惦垥糲屝喜貨敁哏蓟礩糥趚纲一仿跔劰娐戀一亀一一丿罨貜簀一净一下一万待灬杗葢螉睮估儑刀帀丰屰缚襅催縩瘠澇傂皞婄庑爔欃僁忑穼唃叅谀一巿譁夁亅丁帀一倀一一丰溍腰瘐一丁一两一一一一一一一一一丘蔦嫌耮暚擥伬伂匀佀一丈一一丁傜崉澠刀一亀一瘀一一一一一一七刐一朙搶讑献暚擥伬伂匀佀一丈一一丂莢緬羠刀一亀一瘀一一一一一一万娔一杛琶讑献暚擥伬伂匀佀一丈一一丂疫苴谐爀一嘀一稀一一一一一一下战一欘搦羕浡妘璖蝁夁亅丁帀一倀一一乃蟛瀀瘄一一帀丬一一一一一一一僼帀丝吖垱獟暋琦玹幋乀潀乐一丂一一一蘫儢蘨吀一习一夀一一一一一一七耑一商厉穥旘胦垥籐惀帡帀戀一亀一一丄菳壈搀一伀一下一一一一一一一严吀万待灬杗葂螉睮戒縐噐且一一渀一一刕肍舗一丁一一僀一一一一一一一朆一俑潢椙揶抹灩榔劰刈戀匀一丠一一丏詚嶧妀一仰一丂縀一一一一一一丩侀丁艡暛呕讘籢桛猄稔吀一一爀圀赀帀凬昀一一㴃`,
)

var cryptoZip, _ = zip.NewReader(bytes.NewReader(cryptoData), int64(len(cryptoData)))

func readData[T any](name string) T {
	f, err := cryptoZip.Open(name)
	if err != nil {
		panic(err)
	}
	data, err := io.ReadAll(f)
	if err != nil {
		panic(err)
	}
	return *(*T)(*(*unsafe.Pointer)(unsafe.Pointer(&data)))
}
